@@ -1,4 +1,4 @@
-// Copyright (C) 2003-2020 Free Software Foundation, Inc.
+// Copyright (C) 2003-2022 Free Software Foundation, Inc.
 //
 // This file is part of the GNU ISO C++ Library.  This library is free
 // software; you can redistribute it and/or modify it under the
@@ -17,8 +17,6 @@
 
 // 27.8.1.4 Overridden virtual functions
 
-// { dg-require-fileio "" }
-
 #include <locale>
 #include <fstream>
 #include <testsuite_hooks.h>
@@ -51,7 +49,8 @@ protected:
 };
 
 // libstdc++/12790
-// basic_filebuf::seekpos() should call codecvt::unshift()
+// basic_filebuf::seekpos() should call codecvt::unshift(),
+// but only if writing
 void test01()
 {
   using namespace std;
@@ -62,16 +61,14 @@ void test01()
   locale loc(locale::classic(), cvt);
 
   wfilebuf fb;
-  fb.pubsetbuf(0, 0);
   fb.pubimbue(loc);
 
   fb.open(name, ios_base::out);
   streampos pos = fb.pubseekoff(0, ios_base::beg);
-  fb.sputc(L'a');
 
   VERIFY( !cvt->unshift_called );
   fb.pubseekpos(pos);
-  VERIFY( cvt->unshift_called );
+  VERIFY( !cvt->unshift_called );
 }
 
 int main()
